import datetime
from typing import Optional
import telebot

class TelegLog:
    def __init__(self, token: str, chat_id: str):
        self._bot = telebot.TeleBot(token)
        self._chat_id = chat_id

    def send_log(self, template: str):
        self._bot.send_message(self._chat_id, template, parse_mode="Markdown")

    def info(self, message: str):
        template = f"❗**INFO**❗\n{message}\nDate: {datetime.datetime.now().strftime('%d/%m/%Y %H:%M:%S')}"
        
        sending = self.send_log(template)
        

    def error(self, message: str, traceback: Optional[str] = None) -> str:

        if traceback:
            template = f"🚨 **ERROR** 🚨\n{message}\n```python\n{traceback}```\nDate: {datetime.datetime.now().strftime('%d/%m/%Y %H:%M:%S')}"
        else:
            template = f"🚨 **ERROR** 🚨\n{message}\nDate: {datetime.datetime.now().strftime('%d/%m/%Y %H:%M:%S')}"
        
        sending = self.send_log(template)
        
    def warning(self, message: str) -> str:
        template = f"⚠️ **WARNING** ⚠️\n{message}\nDate: {datetime.datetime.now().strftime('%d/%m/%Y %H:%M:%S')}"
        
        sending = self.send_log(template)
        
    def fatal(self, message: str) -> str:
        template = f"🆘 **FATAL** 🆘\n{message}\nDate: {datetime.datetime.now().strftime('%d/%m/%Y %H:%M:%S')}"
        
        sending = self.send_log(template)



from setuptools import setup, find_packages

setup(
    name='teleglog',
    version='0.1.2',
    packages=find_packages(),
    install_requires=[
        'requests>=2.25.1',
        'numpy>=1.21.0',
        'pyTelegramBotAPI>=4.26.0'
    ],
    author='w1tnessbtwwwww (Alexey Surovtsev)',
    author_email='work.w1tnessbtw@mail.ru',
    description='Teleglog Library for make your telegram logging easier.',
    long_description=open('README.md').read(),
    long_description_content_type='text/markdown',
    url='https://github.com/w1tnessbtwwwww/teleglog',
    classifiers=[
        'Programming Language :: Python :: 3.13',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
    ],
    python_requires='>=3.6',
)
